@@ -10,16 +10,18 @@ use Test::Assert ':all';
 
 use IO::Moose::Handle;
 
+use File::Spec;
 use File::Temp;
 use IO::File;
 
 use Scalar::Util 'reftype', 'openhandle', 'tainted';
 
-my ($filename_in, $filename_out, $obj);
+my ($filename_in, $filename_out, $obj, @filenames_out);
 
 sub set_up {
     $filename_in = __FILE__;
-    (undef, $filename_out) = File::Temp::tempfile( 'XXXXXXXX', TMPDIR =>1 );
+    (undef, $filename_out) = File::Temp::tempfile( 'XXXXXXXX', DIR => File::Spec->tmpdir );
+    push @filenames_out, $filename_out;
 
     $obj = IO::Moose::File->new;
     assert_isa('IO::Moose::Handle', $obj);
@@ -27,6 +29,10 @@ sub set_up {
     assert_null(openhandle $obj->fh);
 };
 
+sub DESTROY {
+    unlink foreach @filenames_out;
+};
+
 sub tear_down {
     unlink $filename_out;
 };
